**Example 1: 重启数据库实例mssql-niycdqff**



Input: 

```
tccli sqlserver RestartDBInstance --cli-unfold-argument  \
    --InstanceId mssql-njj2mtpl
```

Output: 
```
{
    "Response": {
        "RequestId": "8a61e500-aa33-454c-9ec2-da2a368c39ab",
        "FlowId": "30321"
    }
}
```

